summaryrefslogtreecommitdiffstats
path: root/kalyptus/kalyptusCxxToSmoke.pm
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-06-20 01:09:59 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-06-20 01:09:59 -0500
commita5ebcd697325e8e6ac9756cc96857d9298d2c114 (patch)
tree83ad2687d35b7c717b2ac5a0c69e61dac17cb0dd /kalyptus/kalyptusCxxToSmoke.pm
parentb9190991168c11cd8a602c3b4490300ac01776fb (diff)
downloadtdebindings-a5ebcd697325e8e6ac9756cc96857d9298d2c114.tar.gz
tdebindings-a5ebcd697325e8e6ac9756cc96857d9298d2c114.zip
Update for recent TQ changes.
Diffstat (limited to 'kalyptus/kalyptusCxxToSmoke.pm')
-rw-r--r--kalyptus/kalyptusCxxToSmoke.pm24
1 files changed, 12 insertions, 12 deletions
diff --git a/kalyptus/kalyptusCxxToSmoke.pm b/kalyptus/kalyptusCxxToSmoke.pm
index 8aa6897f..4c81e93a 100644
--- a/kalyptus/kalyptusCxxToSmoke.pm
+++ b/kalyptus/kalyptusCxxToSmoke.pm
@@ -72,9 +72,9 @@ BEGIN
'char*' => '$',
'TQCOORD*' => '?',
'TQRgb*' => '?',
- 'Q_UINT64' => '$',
- 'Q_INT64' => '$',
- 'Q_LLONG' => '$',
+ 'TQ_UINT64' => '$',
+ 'TQ_INT64' => '$',
+ 'TQ_LLONG' => '$',
'tquint64' => '$',
'qint64' => '$',
'long long' => '$',
@@ -140,21 +140,21 @@ BEGIN
'TQEventLoop::ProcessEventsFlags' => 'uint',
'TQStyle::SCFlags' => 'int',
'TQStyle::SFlags' => 'int',
- 'Q_INT16' => 'short',
+ 'TQ_INT16' => 'short',
'qint16' => 'short',
- 'Q_INT32' => 'int',
+ 'TQ_INT32' => 'int',
'qint32' => 'int',
'qint32&' => 'int&',
- 'Q_INT8' => 'char',
+ 'TQ_INT8' => 'char',
'qint8' => 'char',
- 'Q_LONG' => 'long',
- 'Q_UINT16' => 'ushort',
+ 'TQ_LONG' => 'long',
+ 'TQ_UINT16' => 'ushort',
'tquint16' => 'ushort',
- 'Q_UINT32' => 'uint',
+ 'TQ_UINT32' => 'uint',
'tquint32' => 'uint',
- 'Q_UINT8' => 'uchar',
+ 'TQ_UINT8' => 'uchar',
'tquint8' => 'uchar',
- 'Q_ULONG' => 'long',
+ 'TQ_ULONG' => 'long',
'qreal' => 'double',
'pid_t' => 'int',
'size_t' => 'int',
@@ -1893,7 +1893,7 @@ sub registerType($$) {
}
# Apply typedefs, and store the resulting type.
# For instance, if $type was Q_UINT16&, realType will be ushort
$allTypes{$type}{realType} = applyTypeDef( $realType );
# In the first phase we only create entries into allTypes.
@@ -1893,7 +1893,7 @@ sub registerType($$) {
}
# Apply typedefs, and store the resulting type.
- # For instance, if $type was Q_UINT16&, realType will be ushort
+ # For instance, if $type was TQ_UINT16&, realType will be ushort
$allTypes{$type}{realType} = applyTypeDef( $realType );
# In the first phase we only create entries into allTypes.